summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorRobin McCorkell <rmccorkell@karoshi.org.uk>2014-03-19 20:30:24 +0000
committerRobin McCorkell <rmccorkell@karoshi.org.uk>2014-03-19 20:30:24 +0000
commitca595611f5d9c81a7c6437f4e013bb0ed01a0376 (patch)
treed171056c07eb197eb917c85776dd21868bc48fca
parent01e9e40d83e7929b81ae86d4a7f08517676565f3 (diff)
downloadnextcloud-server-ca595611f5d9c81a7c6437f4e013bb0ed01a0376.tar.gz
nextcloud-server-ca595611f5d9c81a7c6437f4e013bb0ed01a0376.zip
Add FreeIPA UUID compatibility, fixes #7796
Ability to use ipauniqueid for the UUID of a user
-rw-r--r--apps/user_ldap/lib/access.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/apps/user_ldap/lib/access.php b/apps/user_ldap/lib/access.php
index b7e4023dd73..70270a2523e 100644
--- a/apps/user_ldap/lib/access.php
+++ b/apps/user_ldap/lib/access.php
@@ -1064,8 +1064,8 @@ class Access extends LDAPUtility {
return true;
}
- //for now, supported attributes are entryUUID, nsuniqueid, objectGUID
- $testAttributes = array('entryuuid', 'nsuniqueid', 'objectguid', 'guid');
+ //for now, supported attributes are entryUUID, nsuniqueid, objectGUID, ipaUniqueID
+ $testAttributes = array('entryuuid', 'nsuniqueid', 'objectguid', 'guid', 'ipauniqueid', 'ipauniqueid');
foreach($testAttributes as $attribute) {
$value = $this->readAttribute($dn, $attribute);